@@ -122,9 +122,9 @@ politenessProjection <- function(df_polite_train, covar = NULL,
         warning("Note: no cross-validation. Projections in training data are not suitable for accuracy estimation.")
       }
       polite_model<-glmnet::cv.glmnet(x=m_polite_train, y=covar, family=model_family, ...)
-      polite_fit<-stats::predict(polite_model, newx=m_polite_train, s="lambda.1se", type="response")[,1]
+      polite_fit<-stats::predict(polite_model, newx=m_polite_train, s="lambda.min", type="response")[,1]
 
-      p_coefs<-as.matrix(stats::coef(polite_model, s="lambda.1se"))
+      p_coefs<-as.matrix(stats::coef(polite_model, s="lambda.min"))
       polite_coefs<-p_coefs[(!(rownames(p_coefs)=="(Intercept)"))&p_coefs!=0,]
 
     }
