@@ -98,6 +98,10 @@ cleanpunct<-function(text){
   # text<-gsub("’", "'", text)
   # text<-gsub("“", '"', text)
   # text<-gsub("”", '"', text)
+  #text<-gsub(",Äô", '\'', text,fixed=T)
+  text<-gsub(",", ", ", text,fixed=T)
+  text<-gsub(".", ". ", text,fixed=T)
+  text<-gsub(". .", "..", text,fixed=T)
   text<-gsub("[\x84\x93\x94]", '"', text)
   text<-gsub("[\u201C\u201D\u201E\u201F\u2033\u2036]", '"', text)
   text<-gsub("[\x82\x91\x92]", "'", text)
